code
stringlengths
2
1.05M
repo_name
stringlengths
5
114
path
stringlengths
4
991
language
stringclasses
1 value
license
stringclasses
15 values
size
int32
2
1.05M
import React from 'react'; import ReactDOM from 'react-dom'; import { document } from 'global'; import App from './App'; import './index.css'; ReactDOM.render(<App />, document.getElementById('root'));
nfl/react-storybook
examples/test-cra/src/index.js
JavaScript
mit
204
/** * JavaScript code for the "Edit" screen * * @package TablePress * @subpackage Views JavaScript * @author Tobias Bäthge * @since 1.0.0 */ /* global alert, confirm, tp, tablepress_strings, tablepress_options, ajaxurl, QTags, wpLink, tb_show, tb_remove */ // Ensure the global `tp` object exists. window.tp = w...
vilas424/wordpress
wp-content/plugins/tablepress/admin/js/edit.js
JavaScript
gpl-2.0
47,247
var structrt__device__rect__info = [ [ "x", "structrt__device__rect__info.html#aa76f3dd7ea14057db862c7ffad524799", null ], [ "y", "structrt__device__rect__info.html#a11bcb47ee4fddef2852f99a539f045ee", null ], [ "width", "structrt__device__rect__info.html#a1f6ad5365962a838cea665a3db53f2cb", null ], [ "he...
coppercu/iot-neuron
src/osl/rt-thread/rt-thread_1.2.0/documentation/html/structrt__device__rect__info.js
JavaScript
gpl-2.0
407
/** * @author Ed Spencer * * <p>Small helper class to make creating {@link Ext.data.Store}s from JSON data easier. * A JsonStore will be automatically configured with a {@link Ext.data.reader.Json}.</p> * * <p>A store configuration would be something like:</p> * <pre><code> var store = new Ext.data.JsonStore({ ...
jmpolom/ampd
static/extjs4/src/data/JsonStore.js
JavaScript
gpl-3.0
1,687
var moment = require("../../moment"); exports.format = { "format YY" : function(test) { test.expect(1); var b = moment(new Date(2009, 1, 14, 15, 25, 50, 125)); test.equal(b.format('YY'), '09', 'YY ---> 09'); test.done(); }, "format escape brackets" : function(test) { ...
opencodes/node-bootstrap
node_modules/moment/test/moment/format.js
JavaScript
agpl-3.0
4,602
import { moduleForComponent, test } from 'ember-qunit'; import hbs from 'htmlbars-inline-precompile'; moduleForComponent('osf-mode-footer', 'Integration | Component | osf mode footer', { integration: true }); test('it renders', function(assert) { // Set any properties with this.set('myProperty', 'value'); // Ha...
jamescdavis/ember-osf
tests/integration/components/osf-mode-footer/component-test.js
JavaScript
apache-2.0
583
/** * ag-grid - Advanced Data Grid / Data Table supporting Javascript / React / AngularJS / Web Components * @version v16.0.1 * @link http://www.ag-grid.com/ * @license MIT */ "use strict"; var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) { var c = arguments.length, r = c ...
joeyparrish/cdnjs
ajax/libs/ag-grid/16.0.1/lib/valueService/valueService.js
JavaScript
mit
11,792
require('./buildClassName.spec.js'); require('./Menu.spec.js');
instructure-react/react-menu
specs/main.js
JavaScript
mit
64
/* eslint-disable */ ;(function(root, factory) { if (typeof define === 'function' && define.amd) { // AMD define(['../core'], factory); } else if (typeof exports === 'object') { // Node.js module.exports = factory(require('../core')); } else { // Browser root.Blockly.Msg = factory(root.Blockly); } }...
cdnjs/cdnjs
ajax/libs/blockly/7.20211209.4/msg/mg.js
JavaScript
mit
38,441
/* Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved. For licensing, see LICENSE.md or http://ckeditor.com/license */ CKEDITOR.plugins.setLang( 'colordialog', 'bn', { clear: 'Clear', // MISSING highlight: 'Highlight', // MISSING options: 'Color Options', // MISSING selected: 'Selected Color...
gmuro/dolibarr
htdocs/includes/ckeditor/ckeditor/_source/plugins/colordialog/lang/bn.js
JavaScript
gpl-3.0
373
d2hStoreMenuItems("TX__272", [["Documents/notes.htm", "right", "Notes"],["Documents/notes2.htm", "right", "Notes"],["Documents/notes4.htm", "right", "Notes"],["Documents/notes6.htm", "right", "Notes"],["Documents/notes8.htm", "right", "Notes"],["Documents/notes10.htm", "right", "Notes"],["Documents/notes12.htm", "righ...
sanjupolus/kc-coeus-1508.3
coeus-help/src/main/resources/AKLinks/TX__272.js
JavaScript
agpl-3.0
601
/* * Copyright (c) Microsoft Corporation. All rights reserved. * Licensed under the MIT License. See License.txt in the project root for * license information. * * Code generated by Microsoft (R) AutoRest Code Generator. * Changes may cause incorrect behavior and will be lost if the code is * regenerated. */ '...
xingwu1/azure-sdk-for-node
lib/services/consumptionManagement/lib/models/operationListResult.js
JavaScript
apache-2.0
1,744
/** * jqGrid Portuguese Translation * Traduçã da jqGrid em Portugues por Frederico Carvalho, http://www.eyeviewdesign.pt * Dual licensed under the MIT and GPL licenses: * http://www.opensource.org/licenses/mit-license.php * http://www.gnu.org/licenses/gpl.html **/ /*global jQuery, define */ (function( factory ) { ...
gitee2008/glaf
webapps/glaf/static/plugins/jqgrid/js/i18n/grid.locale-pt.js
JavaScript
apache-2.0
6,012
/* * jQuery UI Sortable 1.8.15 * * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about) * Dual licensed under the MIT or GPL Version 2 licenses. * http://jquery.org/license * * http://docs.jquery.com/UI/Sortables * * Depends: * jquery.ui.core.js * jquery.ui.mouse.js * jquery.ui.widget.js */ (function( $...
bmurkoff/ASTPP
web_interface/astpp/assets/js/ui/ui.sortable.js
JavaScript
gpl-2.0
39,946
(function(e){"use strict";function t(e){if(e.hasOwnProperty("id"))return"<span class='elusive'><i class='"+e.id+"'></i>"+"&nbsp;&nbsp;"+e.id.toUpperCase()+"</span>"}e.redux=e.redux||{};e(document).ready(function(){e.redux.select()});e.redux.select=function(){e(".redux-select-item").each(function(){var n={width:"resolve...
davidtromero/net-iq
wp-content/themes/sonnetwp/ReduxFramework/ReduxCore/inc/fields/select/field_select.min.js
JavaScript
gpl-2.0
724
(function ($) { 'use strict'; $.extend(true, $.trumbowyg, { langs: { // jshint camelcase:false en: { fontFamily: 'Font' }, es: { fontFamily: 'Fuente' }, da: { fontFamily: 'Skrifttype'...
nemiah/poolPi
public_html/backend/ubiquitous/CustomerPage/lib/trumbowyg/plugins/fontfamily/trumbowyg.fontfamily.js
JavaScript
gpl-3.0
3,182
// This file was automatically generated. Do not modify. 'use strict'; goog.provide('Blockly.Msg.oc'); goog.require('Blockly.Msg'); Blockly.Msg.ADD_COMMENT = "Apondre un comentari"; Blockly.Msg.CHANGE_VALUE_TITLE = "Modificar la valor :"; Blockly.Msg.CLEAN_UP = "Clean up Blocks"; // untranslated Blockly.Msg.COLLA...
guimotoys/guimo_app_v3
src/assets/blockly/msg/js/oc.js
JavaScript
gpl-3.0
33,156
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */ /* This Source Code Form is subject to the terms of the Mozilla Public * License, v. 2.0. If a copy of the MPL was not distributed with this * file, You can obtain one at http://mozilla.org/MPL/2.0/. */ var gTestfile = 'regress-443569.js...
sainaen/rhino
testsrc/tests/js1_5/extensions/regress-443569.js
JavaScript
mpl-2.0
983
import { Injectable } from '@angular/core'; import { removeArrayItem } from './util'; /** * @hidden */ export class Form { constructor() { this._focused = null; this._ids = -1; this._inputs = []; } /** * @param {?} input * @return {?} */ register(input) { ...
A-HostMobile/MobileApp
node_modules/ionic-angular/es2015/util/form.js
JavaScript
apache-2.0
2,652
/** * @license * Copyright Google Inc. All Rights Reserved. * * Use of this source code is governed by an MIT-style license that can be * found in the LICENSE file at https://angular.io/license */ "use strict"; var Message = (function () { function Message(nodes, placeholders, meaning, description) { ...
oleksandr-minakov/northshore
ui/node_modules/@angular/compiler/src/i18n/i18n_ast.js
JavaScript
apache-2.0
2,906
/** * @requires multirow-row-manager * javelin-install * path-typeahead * javelin-dom * javelin-util * phabricator-prefab * phuix-form-control-view * @provides owners-path-editor * @javelin */ JX.install('OwnersPathEditor', { construct : function(...
phacility/phabricator
webroot/rsrc/js/application/owners/OwnersPathEditor.js
JavaScript
apache-2.0
5,277
/** * @license * Copyright Google Inc. All Rights Reserved. * * Use of this source code is governed by an MIT-style license that can be * found in the LICENSE file at https://angular.io/license */ import { Injectable } from './di/decorators'; import { print, warn } from './facade/lang'; export class Console { ...
oleksandr-minakov/northshore
ui/node_modules/@angular/core/esm/src/console.js
JavaScript
apache-2.0
581
/** * @fileoverview Description of this file. */ /** * Copyright 2019 The AMP HTML Authors. All Rights Reserved. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.a...
lannka/amphtml
examples/visual-tests/amp-sidebar/amp-sidebar-toolbar.js
JavaScript
apache-2.0
1,052
/* YUI 3.17.0 (build ce55cc9) Copyright 2014 Yahoo! Inc. All rights reserved. Licensed under the BSD License. http://yuilibrary.com/license/ */ YUI.add("json-stringify",function(e,t){var n=":",r=e.config.global.JSON;e.mix(e.namespace("JSON"),{dateToString:function(e){function t(e){return e<10?"0"+e:e}return e.getUTCFu...
wayne-lewis/baiducdnstatic
libs/yui/3.17.0/json-stringify/json-stringify-min.js
JavaScript
mit
571
"use strict"; /** * @license * Copyright 2013 Palantir Technologies, Inc. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unle...
rootulp/exercism
typescript/space-age/node_modules/tslint/lib/rules/noParameterPropertiesRule.js
JavaScript
mit
2,681
/** * React Starter Kit (https://www.reactstarterkit.com/) * * Copyright © 2014-present Kriasoft, LLC. All rights reserved. * * This source code is licensed under the MIT license found in the * LICENSE.txt file in the root directory of this source tree. */ /* eslint-disable global-require */ // The top-level (...
machix/mm-inventory
src/routes/index.js
JavaScript
mit
1,109
(function($) { "use strict"; $(document).ready(function() { $(".redux-dimensions-height, .redux-dimensions-width").numeric({ //allowMinus : false, }); $(".redux-dimensions-units").select2({ width: 'resolve', triggerChange: true, allowC...
egamboa/estebangam
wp-content/themes/vcard/ReduxFramework/ReduxCore/inc/fields/dimensions/field_dimensions.js
JavaScript
gpl-2.0
1,150
describe('Controller: ActivationKeyAddSubscriptionsController', function() { var $scope, ActivationKey, SubscriptionsHelper, Nutupane, subscriptions; beforeEach(module('Bastion.activation-keys', 'Bastion.subscriptions', 'Bastion.test-mocks', 'activation-key...
Katello/katello
engines/bastion_katello/test/activation-keys/details/activation-key-add-subscriptions.controller.test.js
JavaScript
gpl-2.0
19,731
chunksize = 25 s = new ShardingTest( "migrate_cursor1" , 2 , 1 , 1 , { chunksize : chunksize } ); s.config.settings.update( { _id: "balancer" }, { $set : { stopped: true } } , true ); s.adminCommand( { enablesharding : "test" } ); db = s.getDB( "test" ) t = db.foo bigString = "" stringSize = 1024; while ( bigStri...
barakav/robomongo
src/third-party/mongodb/jstests/slowNightly/sharding_migrate_cursor1.js
JavaScript
gpl-3.0
1,920
var classgui_1_1controls_1_1gridview_1_1GridModel = [ [ "__init__", "db/db7/classgui_1_1controls_1_1gridview_1_1GridModel.html#ae0fc78a27cd017f93f6a662995607b2e", null ], [ "__init__", "db/db7/classgui_1_1controls_1_1gridview_1_1GridModel.html#ae0fc78a27cd017f93f6a662995607b2e", null ], [ "__delitem__", "db...
google-code-export/gui2py
doc/html/db/db7/classgui_1_1controls_1_1gridview_1_1GridModel.js
JavaScript
lgpl-3.0
1,987
'use strict'; angular.module('lemur'). filter('titleCase', function () { return function (str) { return (str === undefined || str === null) ? '' : str.replace(/([A-Z])/g, ' $1').replace(/^./, function (txt) { return txt.toUpperCase(); }); }; });
rhoml/lemur
lemur/static/app/angular/components/filters.js
JavaScript
apache-2.0
280
// Copyright 2019 the V8 project authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. // Flags: --stack-size=100 let array = new Array(1); array.splice(1, 0, array); assertThrows(() => array.flat(Infinity), RangeError);
zero-rp/miniblink49
v8_7_5/test/mjsunit/regress/regress-8708.js
JavaScript
apache-2.0
304
/* Project: angular-gantt v1.2.3 - Gantt chart component for AngularJS Authors: Marco Schweighauser, Rémi Alvergnat License: MIT Homepage: http://www.angular-gantt.com Github: https://github.com/angular-gantt/angular-gantt.git */ (function(){ 'use strict'; angular.module('gantt.bounds', ['gantt', 'gantt.bounds....
tmthrgd/pagespeed-libraries-cdnjs
packages/angular-gantt/1.2.3/angular-gantt-plugins.js
JavaScript
mit
104,212
/*! * QUnit 1.14.0 * http://qunitjs.com/ * * Copyright 2013 jQuery Foundation and other contributors * Released under the MIT license * http://jquery.org/license * * Date: 2014-01-31T16:40Z */ (function( window ) { var QUnit, assert, config, onErrorFnPrev, testId = 0, fileName = (sourceFromStacktrace( 0...
Vasfed/rails
actionview/test/ujs/public/vendor/qunit.js
JavaScript
mit
61,033
/** * ColorBox.js * * Copyright, Moxiecode Systems AB * Released under LGPL License. * * License: http://www.tinymce.com/license * Contributing: http://www.tinymce.com/contributing */ /** * This widget lets you enter colors and browse for colors by pressing the color button. It also displays * a preview of t...
Grosloup/multisite
web/admin/js/vendor/tinymce/classes/ui/ColorBox.js
JavaScript
mit
1,296
// Collator is not implemented in this polyfill.
zhuyong/ghost_blog
node_modules/intl/src/10.collator.js
JavaScript
mit
49
var assert = require('assert'); var battle; describe('Sticky Hold', function () { afterEach(function () { battle.destroy(); }); it('should prevent held items from being stolen by most moves or abilities', function () { battle = BattleEngine.Battle.construct(); battle.join('p1', 'Guest 1', 1, [{species: 'Shuc...
johtooo/PS
test/simulator/abilities/stickyhold.js
JavaScript
mit
1,629
/** * @author mrdoob / http://mrdoob.com/ */ Sidebar.Animation = function ( editor ) { var signals = editor.signals; var options = {}; var possibleAnimations = {}; var container = new UI.Panel(); container.setDisplay( 'none' ); container.add( new UI.Text( 'Animation' ).setTextTransform( 'uppercase' ) ); c...
tomasparks/retrospacegame
src/js/editor/js/Sidebar.Animation.js
JavaScript
gpl-2.0
2,122
var namespace_mix_e_r_p_1_1_net_1_1_core_1_1_modules_1_1_inventory_1_1_confirmation = [ [ "Adjustment", "class_mix_e_r_p_1_1_net_1_1_core_1_1_modules_1_1_inventory_1_1_confirmation_1_1_adjustment.html", "class_mix_e_r_p_1_1_net_1_1_core_1_1_modules_1_1_inventory_1_1_confirmation_1_1_adjustment" ], [ "Transfer",...
mixerp/mixerp
docs/api/namespace_mix_e_r_p_1_1_net_1_1_core_1_1_modules_1_1_inventory_1_1_confirmation.js
JavaScript
gpl-3.0
980
/** * @fileoverview Tests for no-unused-vars rule. * @author Ilya Volodin */ "use strict"; //------------------------------------------------------------------------------ // Requirements //------------------------------------------------------------------------------ var rule = require("../../../lib/rules/no-unu...
stefanocudini/eslint
tests/lib/rules/no-unused-vars.js
JavaScript
mit
13,598
// A Child of [Backbone.JS][backbone] with Drupal Services defaults. // // // // * TODO Add .TaxonomyCollection with support for taxonomy listings. // * TODO Add .SearchCollection with support for search results. // * TODO Add configurable endpoint path, loaded via Drupal.settings. // (will remove hard dependency on ...
kwiechmann/drupaltutor-d7td
sites/all/modules/contrib/backbone/js/drupalbackbone.js
JavaScript
mit
21,150
/* Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved. For licensing, see LICENSE.md or http://ckeditor.com/license */ CKEDITOR.plugins.setLang("placeholder","nb",{title:"Egenskaper for plassholder",toolbar:"Opprett plassholder",text:"Tekst for plassholder",edit:"Rediger plassholder",textMiss...
Gizra/productivity
wrapboostrap/js/ckeditor/plugins/placeholder/lang/nb.js
JavaScript
gpl-2.0
365
// Copyright 2014 The Chromium Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. function generateSenderIds(size) { var senders = []; for (var i = 0; i < size; i++) { senders.push("Sender" + i); } return senders; } functio...
ChromiumWebApps/chromium
chrome/test/data/extensions/api_test/gcm/functions/register_validation/register_validation.js
JavaScript
bsd-3-clause
1,667
var path = require("path"); var es6 = require("./es6.js"); var log = console.log.bind(console); var child_process = require("child_process"); var chokidar = require('chokidar'); var watcher = chokidar.watch([path.join(__dirname, "../src"), path.join(__dirname, "../test")], { ignored: /[\/\\]\./, persistent: ...
LoveKino/logicer
node_modules/expressioner/build/build.js
JavaScript
mit
1,502
/* This file is part of Ext JS 4.2 Copyright (c) 2011-2013 Sencha Inc Contact: http://www.sencha.com/contact GNU General Public License Usage This file may be used under the terms of the GNU General Public License version 3.0 as published by the Free Software Foundation and appearing in the file LICENSE included in...
lightbase/WSCacicNeo
wscacicneo/static/ext-js/src/tip/ToolTip.js
JavaScript
gpl-2.0
23,432
Proj4js.defs["EPSG:3706"] = "+proj=utm +zone=59 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs";
debard/georchestra-ird
mapfishapp/src/main/webapp/lib/proj4js/lib/defs/EPSG3706.js
JavaScript
gpl-3.0
103
var Screen_BatchEdit = Class.create({}, { prefix: null, actions: Array(), initialize: function(prefix) { this.prefix = prefix; Event.observe (this.prefix + '_action_add_change', 'click', this.action_add_change.bindAsEventListener (this) ); Event.observe (this.prefix + '_action_edit', 'click', thi...
denics/eprints
lib/static/javascript/screen_batchedit.js
JavaScript
gpl-3.0
3,113
Object.defineProperty(Object.prototype, 'x', { set: function() {} }); var obj = {}; for (var i = 0; i < 100 ; ++i) { obj.x = 1; delete obj.x; }
cstipkovic/spidermonkey-research
js/src/jit-test/tests/ion/bug792166-1.js
JavaScript
mpl-2.0
156
//// [undeclaredMethod.ts] module M { export class C { public salt() {} } } var c:M.C = new M.C(); c.salt(); // cool c.saltbar(); // crash //// [undeclaredMethod.js] var M; (function (M) { var C = /** @class */ (function () { function C() { } C.prototype.salt = ...
weswigham/TypeScript
tests/baselines/reference/undeclaredMethod.js
JavaScript
apache-2.0
464
/** * @fileoverview Rule to enforce requiring named capture groups in regular expression. * @author Pig Fang <https://github.com/g-plane> */ "use strict"; //------------------------------------------------------------------------------ // Requirements //-------------------------------------------------------------...
BigBoss424/portfolio
v8/development/node_modules/gatsby/node_modules/eslint/lib/rules/prefer-named-capture-group.js
JavaScript
apache-2.0
3,425
//// [multipleExportDefault4.ts] export default class C { } export default { uhoh: "another default", }; //// [multipleExportDefault4.js] "use strict"; exports.__esModule = true; var C = /** @class */ (function () { function C() { } return C; }()); exports["default"] = C; exports["default"...
basarat/TypeScript
tests/baselines/reference/multipleExportDefault4.js
JavaScript
apache-2.0
360
// DO NOT EDIT! This test has been generated by /html/canvas/tools/gentest.py. // OffscreenCanvas test in a worker:2d.shadow.image.alpha // Description:Shadows are drawn correctly for partially-transparent images // Note: importScripts("/resources/testharness.js"); importScripts("/html/canvas/resources/canvas-tests.js...
chromium/chromium
third_party/blink/web_tests/external/wpt/html/canvas/offscreen/shadows/2d.shadow.image.alpha.worker.js
JavaScript
bsd-3-clause
1,229
import Inline from '../blots/inline'; class Script extends Inline { static create(value) { if (value === 'super') { return document.createElement('sup'); } else if (value === 'sub') { return document.createElement('sub'); } else { return super.create(value); } } static formats(...
wdcxc/blog
static/libs/quill-1.3.0/formats/script.js
JavaScript
mit
544
var struct___i_m_a_g_e___i_m_p_o_r_t___b_y___n_a_m_e = [ [ "Hint", "struct___i_m_a_g_e___i_m_p_o_r_t___b_y___n_a_m_e.html#a4435f791e8ea8c419b57ddfd9aa4ebe2", null ], [ "Name", "struct___i_m_a_g_e___i_m_p_o_r_t___b_y___n_a_m_e.html#a57ca0cc8876e9276aa0047f66df84164", null ] ];
dooooon/Blackbone
doc/driver/html/struct___i_m_a_g_e___i_m_p_o_r_t___b_y___n_a_m_e.js
JavaScript
mit
284
OC.L10N.register( "files_external", { "Fetching request tokens failed. Verify that your app key and secret are correct." : "Holen des Requesttokens fehlgeschlagen. Bitte überprüfe Schlüssel und Secret deiner App.", "Fetching access tokens failed. Verify that your app key and secret are correct." : "Hole...
jbicha/server
apps/files_external/l10n/nds.js
JavaScript
agpl-3.0
5,810
// Vex Flow // Copyright Mohit Cheppudira <mohit@muthanna.com> // // The tickable interface. Tickables are things that sit on a score and // have a duration, i.e., they occupy space in the musical rendering dimension. /** @constructor */ Vex.Flow.Tickable = (function() { function Tickable() { this.init(); } ...
cute/vexflow-musicxml
src/tickable.js
JavaScript
mit
3,764
/** * ag-grid - Advanced Data Grid / Data Table supporting Javascript / React / AngularJS / Web Components * @version v12.0.1 * @link http://www.ag-grid.com/ * @license MIT */ "use strict"; var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) { var c = arguments.length, r = c ...
extend1994/cdnjs
ajax/libs/ag-grid/12.0.1/lib/entities/column.js
JavaScript
mit
21,497
(function (global, factory) { typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() : typeof define === 'function' && define.amd ? define(factory) : (global.Rythm = factory()); }(this, (function () { 'use strict'; var classCallCheck = function (instance, Constructor) { if (!(in...
sufuf3/cdnjs
ajax/libs/rythm.js/2.2.0/rythm.js
JavaScript
mit
13,328
var fs = require('fs'); var path = require('path'); var util = require('util'); var mkpath = require('mkpath'); var Logger = require('../util/logger.js'); var Utils = require('../util/utils.js'); var Q = require('q'); var Reporter = module.exports = function(globalResults, testResults, globalStartTime, options) { th...
madrixx/mocha-chai-basics
node_modules/nightwatch/lib/runner/reporter.js
JavaScript
mit
6,128
frappe.listview_settings['Item'] = { add_fields: ["item_name", "stock_uom", "item_group", "image", "variant_of", "has_variants", "end_of_life", "is_sales_item"], get_indicator: function(doc) { if(doc.end_of_life && doc.end_of_life < frappe.datetime.get_today()) { return [__("Expired"), "grey", "end_of_life,<,...
meisterkleister/erpnext
erpnext/stock/doctype/item/item_list.js
JavaScript
agpl-3.0
643
/* * Copyright 2015 Open Networking Laboratory * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable la...
jinlongliu/onos
apps/demo/cord-gui/src/main/webapp/app/view/user/user.js
JavaScript
apache-2.0
6,423
/*!----------------------------------------------------------- * Copyright (c) Microsoft Corporation. All rights reserved. * Version: 0.5.2(d49899a916fd99840f6f9178f2dd06e0e7013646) * Released under the MIT license * https://github.com/Microsoft/vscode/blob/master/LICENSE.txt *-------------------------------------...
the-gamma/thegamma-olympics-web
web/lib/vs/base/common/worker/simpleWorker.nls.ko.js
JavaScript
mit
1,840
"use strict"; (function(editors, elFinder) { if (typeof define === 'function' && define.amd) { define(['elfinder'], editors); } else if (elFinder) { var optEditors = elFinder.prototype._options.commandsOptions.edit.editors; elFinder.prototype._options.commandsOptions.edit.editors = optEditors.concat(editors(el...
fine-proj/yiishop
vendor/studio-42/elfinder/js/extras/editors.default.js
JavaScript
mit
30,944
/* * /MathJax/jax/output/CommonHTML/config.js * * Copyright (c) 2009-2017 The MathJax Consortium * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/l...
jinntrance/mathjax
jax/output/CommonHTML/config.js
JavaScript
apache-2.0
1,473
/* http://keith-wood.name/calendars.html Amharic localisation for Ethiopian calendar for jQuery v2.1.0. Written by Tewodros Zena February 2010. */ (function($) { 'use strict'; $.calendars.calendars.ethiopian.prototype.regionalOptions.am = { name: 'የኢትዮጵያ ዘመን አቆጣጠር', epochs: ['BEE', 'EE'], monthNa...
ndrmc/cats-web
vendor/assets/javascripts/jquery.calendars/jquery.calendars.ethiopian-am.js
JavaScript
apache-2.0
1,134
/* * SwampDraon 0.2 connection wrapper around SocketJS * By Jonas Hagstedt, 2014 * ----------------------------------- * Usage: * var swampDragon = SwampDragon(options); * swampDragon.connect(); * Options: * onopen: function() called when a connection is established * onclose: function() called when the connec...
h-hirokawa/swampdragon
swampdragon/static/swampdragon/js/swampdragon.js
JavaScript
bsd-3-clause
7,984
/** * ag-grid - Advanced Data Grid / Data Table supporting Javascript / React / AngularJS / Web Components * @version v11.0.0 * @link http://www.ag-grid.com/ * @license MIT */ "use strict"; var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) { var c = arguments.length, r = c ...
wout/cdnjs
ajax/libs/ag-grid/11.0.0/lib/rowModels/inMemory/sortStage.js
JavaScript
mit
2,100
/*global define*/ /*! * This file is used for define the EventProxy library. * @author <a href="mailto:shyvo1987@gmail.com">Jackson Tian</a> * @version 0.3.1 * ``` */ !(function (name, definition) { // Check define var hasDefine = typeof define === 'function', // Check exports hasExports = typeof modul...
PeterDaveHelloKitchen/static
libs/eventproxy/0.3.1/eventproxy.js
JavaScript
mit
17,475
'use strict'; var NodeWatcher = require('./src/node_watcher'); var PollWatcher = require('./src/poll_watcher'); var WatchmanWatcher = require('./src/watchman_watcher'); var FSEventsWatcher = require('./src/fsevents_watcher'); function sane(dir, options) { options = options || {}; if (options.watcher) { var Wa...
gabz75/ember-cli-deploy-redis-publish
node_modules/sane/index.js
JavaScript
mit
858
// Copyright 2016 the V8 project authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. // Flags: --enable-slow-asserts array = new Array(undefined, undefined, undefined); Object.defineProperty(array, 0, { get: function() { array.pus...
weolar/miniblink49
v8_7_5/test/mjsunit/es7/regress/regress-634273.js
JavaScript
apache-2.0
413
// Copyright 2009 the Sputnik authors. All rights reserved. /** * The Date.prototype property "getSeconds" has { DontEnum } attributes * * @path ch15/15.9/15.9.5/15.9.5.22/S15.9.5.22_A1_T3.js * @description Checking DontEnum attribute */ if (Date.prototype.propertyIsEnumerable('getSeconds')) { $ERROR('#1: The ...
Oceanswave/NiL.JS
Tests/tests/sputnik/ch15/15.9/15.9.5/15.9.5.22/S15.9.5.22_A1_T3.js
JavaScript
bsd-3-clause
526
/** * ag-grid - Advanced Data Grid / Data Table supporting Javascript / React / AngularJS / Web Components * @version v10.0.0 * @link http://www.ag-grid.com/ * @license MIT */ "use strict"; var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) { var c = arguments.length, r = c ...
jonobr1/cdnjs
ajax/libs/ag-grid/10.0.0/lib/headerRendering/bodyDropTarget.js
JavaScript
mit
5,591
var searchData= [ ['utils_2epy',['utils.py',['../utils_8py.html',1,'']]] ];
wmde/render-algbackend
doxygen/html/search/files_75.js
JavaScript
gpl-3.0
78
// META: title=EventSource: lines and data parsing var test = async_test(); test.step(function() { var source = new EventSource("resources/message2.py"), counter = 0; source.onmessage = test.step_func(function(e) { if(counter == 0) { assert_equals(e.data,"m...
scheib/chromium
third_party/blink/web_tests/external/wpt/eventsource/event-data.any.js
JavaScript
bsd-3-clause
641
module.exports = function generateApiListDoc() { return { $runAfter: ['extra-docs-added'], $runBefore: ['rendering-docs'], outputFolder: null, $validate: {outputFolder: {presence: true}}, $process: function(docs) { docs.push({ docType: 'api-list-data', template: 'json-doc.te...
mikeybyker/angular
aio/transforms/angular.io-package/processors/generateApiListDoc.js
JavaScript
mit
1,559
var Branches = require('../../../app/collections/branches'), spies = require('../helpers').spies, distate = require('../helpers').distate, mockRepo = require('../models/repo'); module.exports = distate.register(branch); function branch(repo) { return this._branches = this._branches || spies(new Branches([...
AtekiRyu/prose
test/mocks/collections/branches.js
JavaScript
bsd-3-clause
374
// Copyright 2014 The Oppia Authors. All Rights Reserved. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // http://www.apache.org/licenses/LICENSE-2.0 // // Unless required by ap...
kennho/oppia
extensions/rich_text_components/Image/protractor.js
JavaScript
apache-2.0
1,380
/* Copyright (C) 2015 PencilBlue, LLC This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This program is...
benstoltz/pencilblue
include/requirements.js
JavaScript
gpl-3.0
15,129
/* Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved. For licensing, see LICENSE.md or http://ckeditor.com/license */ CKEDITOR.plugins.setLang("widget","tr",{move:"Taşımak için, tıklayın ve sürükleyin"});
Orpheus11/nile
web/plugin/ckeditor/plugins/widget/lang/tr.js
JavaScript
apache-2.0
241
"use strict"; var socket = require("socket.io"); var Steward = require("emitter-steward"); /** * Plugin interface * @returns {*|function(this:exports)} */ module.exports.plugin = function (server, clientEvents, bs) { return exports.init(server, clientEvents, bs); }; /** * @param {http.Server} server * @par...
barkdesignchicago/vidar
wp-content/themes/vidar/node_modules/browser-sync/lib/sockets.js
JavaScript
gpl-2.0
1,915
/* * ***************************************************************************** * Copyright (c) 2012, 2013, 2014 Lectorius, Inc. * Authors: * Vijay Pandurangan (vijayp@mitro.co) * Evan Jones (ej@mitro.co) * Adam Hilss (ahilss@mitro.co) * * * This program is free software: you can redistribute it and/or ...
WeAreWizards/passopolis-extensions
login/frontend/static/js/roboform_browsertest.js
JavaScript
gpl-3.0
3,670
module["exports"] = [ "#{street_name} #{building_number}", "#{street_name} #{building_number}, #{secondary_address}" ];
xinhuafan/Reddit-Clone
node_modules/faker/lib/locales/it/address/street_address.js
JavaScript
gpl-2.0
124
var address = {}; module['exports'] = address; address.city_prefix = require("./city_prefix"); address.city_suffix = require("./city_suffix"); address.country = require("./country"); address.building_number = require("./building_number"); address.secondary_address = require("./secondary_address"); address.postcode = re...
together-web-pj/together-web-pj
node_modules/faker/lib/locales/sk/address/index.js
JavaScript
gpl-3.0
741
define([ 'jquery', 'summernote/base/core/list', 'summernote/base/Context' ], function ($, list, Context) { $.fn.extend({ /** * Summernote API * * @param {Object|String} * @return {this} */ summernote: function () { var type = $.type(list.head(arguments)); var isExter...
jimolina/bakeangular
webroot/bower_components/summernote/src/js/summernote.js
JavaScript
mit
1,367
(function (global, factory) { typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() : typeof define === 'function' && define.amd ? define(factory) : (global.page = factory()); }(this, (function () { 'use strict'; var isarray = Array.isArray || function (arr) { return Object.pro...
sufuf3/cdnjs
ajax/libs/page.js/1.8.5/page.js
JavaScript
mit
27,455
timing_test(function() { at( 0.0, function() {assert_styles('#a', {'left':'0px'})}, "Autogenerated test at t= 0.0"); at( 1.0, function() {assert_styles('#a', {'left':'50px'})}, "Autogenerated test at t= 1.0"); at( 2.0, function() {assert_styles('#a', {'left':'100px'})}, "Autogenerated test at t= 2.0"); at( 3.0,...
passiweinberger/passiweinberger.github.io
webgl-globe/polymer-globe/polymer/polymer-all/web-animations-js/test/testcases/test-change-playback-rate-checks.js
JavaScript
apache-2.0
1,899
/*! * Copyright 2014 Drifty Co. * http://drifty.com/ * * Ionic, v1.0.0-beta.1 * A powerful HTML5 mobile app framework. * http://ionicframework.com/ * * By @maxlynch, @benjsperry, @adamdbradley <3 * * Licensed under the MIT license. Please see LICENSE for more information. * */ (function() { // Create name...
bio2rdf/bio2rdf-mobile
www/lib/version/1.0.0-beta.1-actinium/js/ionic.js
JavaScript
mit
224,258
/** * revisr-dashboard.js * * Processes AJAX functionality on the Revisr dashboard. * * @package Revisr * @license GPLv3 * @link https://revisr.io * @copyright Expanded Fronts, LLC */ (function( $ ) { 'use strict'; /** * Refresh the Revisr status bar after any transients have expired. */ functio...
surgemedia/cakewebsite
wp-content/plugins/revisr/assets/js/revisr-dashboard.js
JavaScript
gpl-2.0
7,782
frappe.ui.form.on("Employee Attendance Tool", { refresh: function(frm) { frm.disable_save(); }, onload: function(frm) { frm.doc.department = frm.doc.branch = frm.doc.company = "All"; frm.set_value("date", frappe.datetime.get_today()); erpnext.employee_attendance_tool.load_employees(frm); }, date: functi...
ovresko/erpnext
erpnext/hr/doctype/employee_attendance_tool/employee_attendance_tool.js
JavaScript
gpl-3.0
6,651
/** List of checkboxes. Internally value stored as javascript array of values. @class checklist @extends list @final @example <a href="#" id="options" data-type="checklist" data-pk="1" data-url="/post" data-original-title="Select options"></a> <script> $(function(){ $('#options').editable({ value: [2, 3],...
WilliamRen/cdnjs
ajax/libs/x-editable/1.4.1/inputs/checklist.js
JavaScript
mit
4,537
angular.module('linkify', []); angular.module('linkify') .filter('linkify', function () { 'use strict'; function linkify (_str, type) { if (!_str) { return; } function addProtocol (url) { if(/(([\w]+:)?\/\/)/ig.test(url) === false) { url = 'http:/...
scottcorgan/angular-linkify
angular-linkify.js
JavaScript
mit
2,383
// Copyright (c) 2013, Web Notes Technologies Pvt. Ltd. and Contributors // License: GNU General Public License v3. See license.txt cur_frm.cscript.refresh = function(doc, cdt, cdn) { cur_frm.toggle_enable('new_item_code', doc.__islocal); if(!doc.__islocal) { cur_frm.add_custom_button(wn._("Check for Duplicates"),...
saurabh6790/test-med-app
selling/doctype/sales_bom/sales_bom.js
JavaScript
agpl-3.0
926
function Create(command, params, item) { var channel, room, user; if (command !== 'create' || !Match.test(params, String)) { return; } channel = params.trim(); if (channel === '') { return; } user = Meteor.users.findOne(Meteor.userId()); room = RocketChat.models.Rooms.findOneByName(channel); if (room != n...
abduljanjua/TheHub
packages/rocketchat-slashcommands-create/server.js
JavaScript
mit
685
// floating label (function ($) { 'use strict'; $.fn.floatingLabel = function (option) { var parent = this.closest('.form-group-label'); if (parent.length) { switch (option) { case 'focusin': parent.addClass('control-focus'); break; case 'focusout': parent.removeClass('contr...
barosclub/ahr
themes/material/assets2/js/form-adv-label.js
JavaScript
bsd-3-clause
1,048
(function (global, factory) { typeof exports === 'object' && typeof module !== 'undefined' ? factory() : typeof define === 'function' && define.amd ? define(factory) : (factory()); }(this, (function () { 'use strict'; function reframe(target, cName) { var frames = typeof target === 'string' ? document.querySelect...
sashberd/cdnjs
ajax/libs/reframe.js/2.2.1/jquery.reframe.js
JavaScript
mit
1,621
import React from 'react'; import pure from 'recompose/pure'; import SvgIcon from '../../SvgIcon'; let CommunicationCallSplit = (props) => ( <SvgIcon {...props}> <path d="M14 4l2.29 2.29-2.88 2.88 1.42 1.42 2.88-2.88L20 10V4zm-4 0H4v6l2.29-2.29 4.71 4.7V20h2v-8.41l-5.29-5.3z"/> </SvgIcon> ); CommunicationCallS...
hwo411/material-ui
src/svg-icons/communication/call-split.js
JavaScript
mit
504
Template.ionFooterBar.rendered = function () { Session.set('hasFooter', true); }; Template.ionFooterBar.destroyed = function () { Session.set('hasFooter', false); }; Template.ionFooterBar.helpers({ classes: function () { var classes = ['bar', 'bar-footer']; if (this.class) { classes.push(this.cla...
Compy/GNUYak
packages/compy_ionic/components/ionFooterBar/ionFooterBar.js
JavaScript
mit
490
/** * Module dependencies. */ var parseuri = require('parseuri'); var debug = require('debug')('socket.io-client:url'); /** * Module exports. */ module.exports = url; /** * URL parser. * * @param {String} url * @param {Object} An object meant to mimic window.location. * Defaults to window....
BigBoss424/portfolio
v8/development/node_modules/socket.io-client/lib/url.js
JavaScript
apache-2.0
1,644
/** * Copyright (c) 2015-present, Facebook, Inc. * All rights reserved. * * This source code is licensed under the BSD-style license found in the * LICENSE file in the root directory of this source tree. An additional grant * of patent rights can be found in the PATENTS file in the same directory. * * @provides...
dggriffin/react-native-mariomakely
node_modules/react-native/Libraries/Components/Navigation/NavigatorIOS.ios.js
JavaScript
mit
21,302
/** * @preserve HTML5 Shiv 3.7.3-pre | @afarkas @jdalton @jon_neal @rem | MIT/GPL2 Licensed */ ;(function(window, document) { /*jshint evil:true */ /** version */ var version = '3.7.3'; /** Preset options */ var options = window.html5 || {}; /** Used to skip problem elements */ var reSkip = /^<|^(?:button...
synchronit/synchronit_website
zensum/node_modules/html5shiv/src/html5shiv-printshiv.js
JavaScript
apache-2.0
16,272